@@ -22,10 +22,8 @@
 
 #include <zorp/urlfilter.h>
 
-UrlFilter::UrlFilter()
-{
-}
-
-UrlFilter::~UrlFilter()
+bool
+UrlFilter::is_initialized() const
 {
+  return initialized;
 }
